pub struct AirProvingContext<PB: ProverBackend> {
pub cached_mains: Vec<CommittedTraceData<PB>>,
pub common_main: PB::Matrix,
pub public_values: Vec<PB::Val>,
}Fields
cached_mains: Vec<CommittedTraceData<PB>>Cached main trace matrices as PcsData. The original trace matrix should be extractable as
a view from the PcsData. The PcsData should also contain the commitment value. Cached
trace commitments have a single matrix per commitment.
The PcsData is kept inside an Arc to emphasize that this data is cached and may be
shared between multiple proving contexts. In particular, it is not typically safe to mutate
the data during a proving job.
common_main: PB::MatrixCommon main trace matrix
public_values: Vec<PB::Val>Public values
Implementations
Sourceimpl<PB: ProverBackend> AirProvingContext<PB>
impl<PB: ProverBackend> AirProvingContext<PB>
Sourceimpl<PB: ProverBackend> AirProvingContext<PB>
impl<PB: ProverBackend> AirProvingContext<PB>