pub struct CommittedTraceData<PB: ProverBackend> {
pub commitment: PB::Commitment,
pub trace: PB::Matrix,
pub data: Arc<PB::PcsData>,
}Expand description
The committed trace data for a single trace matrix. This type is used to store prover data for both preprocessed trace and cached trace.
Fields
commitment: PB::CommitmentThe polynomial commitment.
trace: PB::MatrixThe trace matrix, unstacked, in evaluation form.
data: Arc<PB::PcsData>The PCS data for a single committed trace matrix.
Implementations
Sourceimpl<PB: ProverBackend> CommittedTraceData<PB>
impl<PB: ProverBackend> CommittedTraceData<PB>