HostProof

Struct HostProof 

pub struct HostProof<SC: StarkProtocolConfig, PB: ProverBackend, ConstraintsProof, OpeningProof> {
    pub common_main_commit: PB::Commitment,
    pub trace_vdata: Vec<Option<TraceVData<SC>>>,
    pub public_values: Vec<Vec<PB::Val>>,
    pub constraints_proof: ConstraintsProof,
    pub opening_proof: OpeningProof,
}
Proof on the host, with respect to the host types in the generic PB.

Fields

common_main_commit: PB::Commitment

The commitment to the data in common_main.

trace_vdata: Vec<Option<TraceVData<SC>>>

For each AIR in vkey order, the corresponding trace shape, or None if the trace is empty. In a valid proof, if vk.per_air[i].is_required, then trace_vdata[i] must be Some(_).

public_values: Vec<Vec<PB::Val>>

For each AIR in vkey order, the public values. Public values should be empty if the AIR has an empty trace.

constraints_proof: ConstraintsProofopening_proof: OpeningProof

Opening proof for multiple polynomials over mixed sized domains