LogupZerocheckCpu

Struct LogupZerocheckCpu 

pub struct LogupZerocheckCpu<'a, SC: StarkProtocolConfig> {
Show 13 fields pub alpha_logup: SC::EF, pub beta_pows: Vec<SC::EF>, pub l_skip: usize, pub n_logup: usize, pub n_max: usize, pub omega_skip: SC::F, pub omega_skip_pows: Vec<SC::F>, pub interactions_layout: StackedLayout, pub constraint_degree: usize, pub n_per_trace: Vec<isize>, pub xi: Vec<SC::EF>, pub mat_evals_per_trace: Vec<Vec<ColMajorMatrix<SC::EF>>>, pub sels_per_trace: Vec<ColMajorMatrix<SC::EF>>, /* private fields */
}

Fields

alpha_logup: SC::EFbeta_pows: Vec<SC::EF>l_skip: usizen_logup: usizen_max: usizeomega_skip: SC::Fomega_skip_pows: Vec<SC::F>interactions_layout: StackedLayoutconstraint_degree: usize

Max constraint degree across constraints and interactions

n_per_trace: Vec<isize>xi: Vec<SC::EF>mat_evals_per_trace: Vec<Vec<ColMajorMatrix<SC::EF>>>sels_per_trace: Vec<ColMajorMatrix<SC::EF>>

Implementations

Source

impl<'a, SC: StarkProtocolConfig> LogupZerocheckCpu<'a, SC>
where SC::F: TwoAdicField, SC::EF: TwoAdicField + ExtensionField<SC::F>, CpuColMajorBackend<SC>: ProverBackend<Val = SC::F, Matrix = ColMajorMatrix<SC::F>>,

pub fn new( pk: &'a DeviceMultiStarkProvingKey<CpuColMajorBackend<SC>>, ctx: &ProvingContext<CpuColMajorBackend<SC>>, n_logup: usize, interactions_layout: StackedLayout, alpha_logup: SC::EF, beta_logup: SC::EF, ) -> Result<Self, LogupZerocheckError>

pub fn sumcheck_uni_round0_polys( &mut self, ctx: &ProvingContext<CpuColMajorBackend<SC>>, lambda: SC::EF, ) -> Result<Vec<UnivariatePoly<SC::EF>>, LogupZerocheckError>

Returns the s_0 polynomials in coefficient form. There should be exactly num_airs_present \* 3 polynomials, in the order (s_0)_{p,T}, (s_0)_{q,T}, (s_0)_{zerocheck,T} per trace T. This is computed before sampling batching randomness mu because the result is used to observe the sum claims sum_{p,T}, sum_{q,T}. The s_0 polynomials could be returned in either coefficient or evaluation form, but we return them all in coefficient form for uniformity and debugging since this interpolation is inexpensive.

pub fn fold_ple_evals( &mut self, ctx: &ProvingContext<CpuColMajorBackend<SC>>, r_0: SC::EF, )

After univariate sumcheck round 0, fold prismalinear evaluations using randomness r_0. Folding could directly mutate inplace the trace matrices in ctx as they will not be needed after this.

pub fn sumcheck_polys_eval( &mut self, round: usize, r_prev: SC::EF, ) -> Result<Vec<Vec<SC::EF>>, LogupZerocheckError>

Returns length 3 * num_airs_present polynomials, each polynomial either evaluated at 1,...,deg(s') or at 1 if a linear term (terms in front-loaded sumcheck that have reached exhaustion)

pub fn fold_mle_evals(&mut self, round: usize, r_round: SC::EF)

pub fn into_column_openings( &mut self, ) -> Result<Vec<Vec<Vec<SC::EF>>>, LogupZerocheckError>